@@ -12,13 +12,13 @@
 #include "TracySortedVector.hpp"
 #include "TracyVector.hpp"
 #include "tracy_robin_hood.h"
-#include "../common/TracyForceInline.hpp"
-#include "../common/TracyQueue.hpp"
+#include "../public/common/TracyForceInline.hpp"
+#include "../public/common/TracyQueue.hpp"
 
 namespace tracy
 {
 
-#pragma pack( 1 )
+#pragma pack( push, 1 )
 
 struct StringRef
 {
@@ -355,6 +355,41 @@ enum { MaxLockThreads = sizeof( LockEventPtr::waitList ) * 8 };
 static_assert( std::numeric_limits<decltype(LockEventPtr::lockCount)>::max() >= MaxLockThreads, "Not enough space for lock count." );
 
 
+enum class LockType : uint8_t;
+
+struct LockMap
+{
+    struct TimeRange
+    {
+        int64_t start = std::numeric_limits<int64_t>::max();
+        int64_t end = std::numeric_limits<int64_t>::min();
+    };
+
+    StringIdx customName;
+    int16_t srcloc;
+    Vector<LockEventPtr> timeline;
+    unordered_flat_map<uint64_t, uint8_t> threadMap;
+    std::vector<uint64_t> threadList;
+    LockType type;
+    int64_t timeAnnounce;
+    int64_t timeTerminate;
+    bool valid;
+    bool isContended;
+    uint64_t lockingThread;
+
+    TimeRange range[64];
+};
+
+struct LockHighlight
+{
+    int64_t id;
+    int64_t begin;
+    int64_t end;
+    uint8_t thread;
+    bool blocked;
+};
+
+
 struct GpuEvent
 {
     tracy_force_inline int64_t CpuStart() const { return int64_t( _cpuStart_srcloc ) >> 16; }
@@ -628,7 +663,7 @@ struct ChildSample
 
 enum { ChildSampleSize = sizeof( ChildSample ) };
 
-#pragma pack()
+#pragma pack( pop )
 
 
 struct ThreadData
@@ -686,38 +721,6 @@ struct GpuCtxData
 
 enum { GpuCtxDataSize = sizeof( GpuCtxData ) };
 
-enum class LockType : uint8_t;
-
-struct LockMap
-{
-    struct TimeRange
-    {
-        int64_t start = std::numeric_limits<int64_t>::max();
-        int64_t end = std::numeric_limits<int64_t>::min();
-    };
-
-    StringIdx customName;
-    int16_t srcloc;
-    Vector<LockEventPtr> timeline;
-    unordered_flat_map<uint64_t, uint8_t> threadMap;
-    std::vector<uint64_t> threadList;
-    LockType type;
-    int64_t timeAnnounce;
-    int64_t timeTerminate;
-    bool valid;
-    bool isContended;
-
-    TimeRange range[64];
-};
-
-struct LockHighlight
-{
-    int64_t id;
-    int64_t begin;
-    int64_t end;
-    uint8_t thread;
-    bool blocked;
-};
 
 enum class PlotType : uint8_t
 {
@@ -744,6 +747,11 @@ struct PlotData
     SortedVector<PlotItem, PlotItemSort> data;
     PlotType type;
     PlotValueFormatting format;
+    uint8_t showSteps;
+    uint8_t fill;
+    uint32_t color;
+
+    double rMin, rMax, num;
 };
 
 struct MemData
