@@ -6,9 +6,11 @@
 namespace tracy
 {
 
+void InitTexture();
 void* MakeTexture();
 void FreeTexture( void* tex, void(*runOnMainThread)(std::function<void()>, bool) );
 void UpdateTexture( void* tex, const char* data, int w, int h );
+void UpdateTextureRGBA( void* tex, void* data, int w, int h );
 
 }
 
