@@ -1,34 +1,42 @@
 #ifndef __TRACYVIEW_HPP__
 #define __TRACYVIEW_HPP__
 
+#include <array>
 #include <atomic>
 #include <functional>
-#include <map>
 #include <memory>
 #include <string>
 #include <thread>
 #include <vector>
 
+#include "imgui.h"
+
 #include "TracyBadVersion.hpp"
 #include "TracyBuzzAnim.hpp"
 #include "TracyDecayValue.hpp"
 #include "TracyFileWrite.hpp"
-#include "TracyImGui.hpp"
 #include "TracyShortPtr.hpp"
 #include "TracySourceContents.hpp"
-#include "TracyTexture.hpp"
+#include "TracyTimelineController.hpp"
 #include "TracyUserData.hpp"
+#include "TracyUtility.hpp"
 #include "TracyVector.hpp"
 #include "TracyViewData.hpp"
 #include "TracyWorker.hpp"
 #include "tracy_robin_hood.h"
 
-struct ImVec2;
-struct ImFont;
-
 namespace tracy
 {
 
+constexpr const char* GpuContextNames[] = {
+    "Invalid",
+    "OpenGL",
+    "Vulkan",
+    "OpenCL",
+    "Direct3D 12",
+    "Direct3D 11"
+};
+
 struct MemoryPage;
 class FileRead;
 class SourceView;
@@ -73,15 +81,6 @@ class View
     };
 
 public:
-    struct VisData
-    {
-        bool visible = true;
-        bool showFull = true;
-        bool ghost = false;
-        int offset = 0;
-        int height = 0;
-    };
-
     struct PlotView
     {
         double min;
@@ -89,15 +88,15 @@ public:
     };
 
     using SetTitleCallback = void(*)( const char* );
-    using GetWindowCallback = void*(*)();
     using SetScaleCallback = void(*)( float, ImFont*&, ImFont*&, ImFont*& );
+    using AttentionCallback = void(*)();
 
-    View( void(*cbMainThread)(std::function<void()>, bool), ImFont* fixedWidth = nullptr, ImFont* smallFont = nullptr, ImFont* bigFont = nullptr, SetTitleCallback stcb = nullptr, GetWindowCallback gwcb = nullptr, SetScaleCallback sscb = nullptr ) : View( cbMainThread, "127.0.0.1", 8086, fixedWidth, smallFont, bigFont, stcb, gwcb, sscb ) {}
-    View( void(*cbMainThread)(std::function<void()>, bool), const char* addr, uint16_t port, ImFont* fixedWidth = nullptr, ImFont* smallFont = nullptr, ImFont* bigFont = nullptr, SetTitleCallback stcb = nullptr, GetWindowCallback gwcb = nullptr, SetScaleCallback sscb = nullptr );
-    View( void(*cbMainThread)(std::function<void()>, bool), FileRead& f, ImFont* fixedWidth = nullptr, ImFont* smallFont = nullptr, ImFont* bigFont = nullptr, SetTitleCallback stcb = nullptr, GetWindowCallback gwcb = nullptr, SetScaleCallback sscb = nullptr );
+    View( void(*cbMainThread)(std::function<void()>, bool), const char* addr, uint16_t port, ImFont* fixedWidth, ImFont* smallFont, ImFont* bigFont, SetTitleCallback stcb, SetScaleCallback sscb, AttentionCallback acb );
+    View( void(*cbMainThread)(std::function<void()>, bool), FileRead& f, ImFont* fixedWidth, ImFont* smallFont, ImFont* bigFont, SetTitleCallback stcb, SetScaleCallback sscb, AttentionCallback acb );
     ~View();
 
-    static bool Draw();
+    bool Draw();
+    bool WasActive() const;
 
     void NotifyRootWindowSize( float w, float h ) { m_rootWidth = w; m_rootHeight = h; }
     void ViewSource( const char* fileName, int line );
@@ -111,21 +110,27 @@ public:
     const char* SourceSubstitution( const char* srcFile ) const;
 
     void ShowSampleParents( uint64_t symAddr, bool withInlines ) { m_sampleParents.symAddr = symAddr; m_sampleParents.sel = 0; m_sampleParents.withInlines = withInlines; }
+
+    ViewData& GetViewData() { return m_vd; }
     const ViewData& GetViewData() const { return m_vd; }
 
+    ShortenName GetShortenName() const { return m_shortenName; }
+    int GetNextGpuIdx() { return m_gpuIdx++; }
+
+    void HighlightThread( uint64_t thread );
+    void ZoomToRange( int64_t start, int64_t end, bool pause = true );
+    bool DrawPlot( PlotData& plot, double pxns, int& offset, const ImVec2& wpos, bool hover, float yMin, float yMax );
+    bool DrawThread( const ThreadData& thread, double pxns, int& offset, const ImVec2& wpos, bool hover, float yMin, float yMax, bool ghostMode );
+    void DrawThreadMessages( const ThreadData& thread, double pxns, int offset, const ImVec2& wpos, bool hover );
+    void DrawThreadOverlays( const ThreadData& thread, const ImVec2& ul, const ImVec2& dr );
+    bool DrawGpu( const GpuCtxData& gpu, double pxns, int& offset, const ImVec2& wpos, bool hover, float yMin, float yMax );
+    bool DrawCpuData( double pxns, int& offset, const ImVec2& wpos, bool hover, float yMin, float yMax );
 
     bool m_showRanges = false;
     Range m_statRange;
     Range m_waitStackRange;
 
 private:
-    enum class Namespace : uint8_t
-    {
-        Full,
-        Mid,
-        Short
-    };
-
     enum class ShortcutAction : uint8_t
     {
         None,
@@ -147,6 +152,32 @@ private:
         LastRange
     };
 
+    enum class MemRange
+    {
+        Full,
+        Active,
+        Inactive
+    };
+
+    struct KeyboardNavigation
+    {
+        enum Direction
+        {
+            // Pan left / right
+            Left,
+            Right,
+            // Zoom in / out
+            In,
+            Out
+        };
+
+        constexpr static auto DirectionToKeyMap = std::array<ImGuiKey, 4> { ImGuiKey_A, ImGuiKey_D, ImGuiKey_W, ImGuiKey_S };
+        constexpr static auto StartRangeMod = std::array<int, 4> { -1, 1, 1, -1 };
+        constexpr static auto EndRangeMod = std::array<int, 4> { -1, 1, -1, 1 };
+
+        std::array<float, 4> m_scrollInertia;
+    };
+
     struct ZoneColorData
     {
         uint32_t color;
@@ -165,17 +196,13 @@ private:
     void InitMemory();
     void InitTextEditor( ImFont* font );
 
-    const char* ShortenNamespace( const char* name ) const;
-
-    void DrawHelpMarker( const char* desc ) const;
-
     bool DrawImpl();
     void DrawNotificationArea();
     bool DrawConnection();
     void DrawFrames();
-    void DrawZoneFramesHeader();
-    void DrawZoneFrames( const FrameData& frames );
-    void DrawZones();
+    void DrawTimelineFramesHeader();
+    void DrawTimelineFrames( const FrameData& frames );
+    void DrawTimeline();
     void DrawContextSwitches( const ContextSwitch* ctx, const Vector<SampleData>& sampleData, bool hover, double pxns, int64_t nspx, const ImVec2& wpos, int offset, int endOffset, bool isFiber );
     void DrawSamples( const Vector<SampleData>& vec, bool hover, double pxns, int64_t nspx, const ImVec2& wpos, int offset );
 #ifndef TRACY_NO_STATISTICS
@@ -195,10 +222,8 @@ private:
     int SkipGpuZoneLevel( const V& vec, bool hover, double pxns, int64_t nspx, const ImVec2& wpos, int offset, int depth, uint64_t thread, float yMin, float yMax, int64_t begin, int drift );
     void DrawLockHeader( uint32_t id, const LockMap& lockmap, const SourceLocation& srcloc, bool hover, ImDrawList* draw, const ImVec2& wpos, float w, float ty, float offset, uint8_t tid );
     int DrawLocks( uint64_t tid, bool hover, double pxns, const ImVec2& wpos, int offset, LockHighlight& highlight, float yMin, float yMax );
-    int DrawPlots( int offset, double pxns, const ImVec2& wpos, bool hover, float yMin, float yMax );
     void DrawPlotPoint( const ImVec2& wpos, float x, float y, int offset, uint32_t color, bool hover, bool hasPrev, const PlotItem* item, double prev, bool merged, PlotType type, PlotValueFormatting format, float PlotHeight, uint64_t name );
     void DrawPlotPoint( const ImVec2& wpos, float x, float y, int offset, uint32_t color, bool hover, bool hasPrev, double val, double prev, bool merged, PlotValueFormatting format, float PlotHeight );
-    int DrawCpuData( int offset, double pxns, const ImVec2& wpos, bool hover, float yMin, float yMax );
     void DrawOptions();
     void DrawMessages();
     void DrawMessageLine( const MessageData& msg, bool hasCallstack, int& idx );
@@ -227,7 +252,7 @@ private:
 
     void ListMemData( std::vector<const MemEvent*>& vec, std::function<void(const MemEvent*)> DrawAddress, const char* id = nullptr, int64_t startTime = -1, uint64_t pool = 0 );
 
-    unordered_flat_map<uint32_t, MemPathData> GetCallstackPaths( const MemData& mem, bool onlyActive ) const;
+    unordered_flat_map<uint32_t, MemPathData> GetCallstackPaths( const MemData& mem, MemRange memRange ) const;
     unordered_flat_map<uint64_t, MemCallstackFrameTree> GetCallstackFrameTreeBottomUp( const MemData& mem ) const;
     unordered_flat_map<uint64_t, MemCallstackFrameTree> GetCallstackFrameTreeTopDown( const MemData& mem ) const;
     void DrawFrameTreeLevel( const unordered_flat_map<uint64_t, MemCallstackFrameTree>& tree, int& idx );
@@ -251,7 +276,10 @@ private:
     void DrawGpuInfoChildren( const V& children, int64_t ztime );
 
     void HandleRange( Range& range, int64_t timespan, const ImVec2& wpos, float w );
-    void HandleZoneViewMouse( int64_t timespan, const ImVec2& wpos, float w, double& pxns );
+    void HandleTimelineMouse( int64_t timespan, const ImVec2& wpos, float w, double& pxns );
+    void HandleTimelineKeyboard( int64_t timespan, const ImVec2& wpos, float w );
+
+    void AddAnnotation( int64_t start, int64_t end );
 
     uint32_t GetThreadColor( uint64_t thread, int depth );
     uint32_t GetSrcLocColor( const SourceLocation& srcloc, int depth );
@@ -263,7 +291,6 @@ private:
 
     void ZoomToZone( const ZoneEvent& ev );
     void ZoomToZone( const GpuEvent& ev );
-    void ZoomToRange( int64_t start, int64_t end, bool pause = true );
     void ZoomToPrevFrame();
     void ZoomToNextFrame();
     void CenterAtTime( int64_t t );
@@ -279,6 +306,7 @@ private:
 
     const ZoneEvent* GetZoneParent( const ZoneEvent& zone ) const;
     const ZoneEvent* GetZoneParent( const ZoneEvent& zone, uint64_t tid ) const;
+    const ZoneEvent* GetZoneChild( const ZoneEvent& zone, int64_t time ) const;
     bool IsZoneReentry( const ZoneEvent& zone ) const;
     bool IsZoneReentry( const ZoneEvent& zone, uint64_t tid ) const;
     const GpuEvent* GetZoneParent( const GpuEvent& zone ) const;
@@ -290,6 +318,8 @@ private:
     const ZoneEvent* FindZoneAtTime( uint64_t thread, int64_t time ) const;
     uint64_t GetFrameNumber( const FrameData& fd, int i, uint64_t offset ) const;
     const char* GetFrameText( const FrameData& fd, int i, uint64_t ftime, uint64_t offset ) const;
+    const char* GetFrameSetName( const FrameData& fd ) const;
+    static const char* GetFrameSetName( const FrameData& fd, const Worker& worker );
 
 #ifndef TRACY_NO_STATISTICS
     void FindZones();
@@ -297,7 +327,6 @@ private:
 #endif
 
     std::vector<MemoryPage> GetMemoryPages() const;
-    const char* GetPlotName( const PlotData* plot ) const;
 
     void SmallCallstackButton( const char* name, uint32_t callstack, int& idx, bool tooltip = true );
     void DrawCallstackCalls( uint32_t callstack, uint16_t limit ) const;
@@ -321,7 +350,8 @@ private:
     void SetPlaybackFrame( uint32_t idx );
     bool Save( const char* fn, FileWrite::Compression comp, int zlevel, bool buildDict );
 
-    unordered_flat_map<const void*, VisData> m_visData;
+    void Attention( bool& alreadyDone );
+
     unordered_flat_map<uint64_t, bool> m_visibleMsgThread;
     unordered_flat_map<uint64_t, bool> m_waitStackThread;
     unordered_flat_map<const void*, int> m_gpuDrift;
@@ -329,16 +359,6 @@ private:
     Vector<const ThreadData*> m_threadOrder;
     Vector<float> m_threadDnd;
 
-    tracy_force_inline VisData& Vis( const void* ptr )
-    {
-        auto it = m_visData.find( ptr );
-        if( it == m_visData.end() )
-        {
-            it = m_visData.emplace( ptr, VisData {} ).first;
-        }
-        return it->second;
-    }
-
     tracy_force_inline bool& VisibleMsgThread( uint64_t thread )
     {
         auto it = m_visibleMsgThread.find( thread );
@@ -369,7 +389,19 @@ private:
         return it->second;
     }
 
-    void AdjustThreadHeight( View::VisData& vis, int oldOffset, int& offset );
+    static int64_t AdjustGpuTime( int64_t time, int64_t begin, int drift );
+
+    static const char* DecodeContextSwitchState( uint8_t state );
+    static const char* DecodeContextSwitchStateCode( uint8_t state );
+    static const char* DecodeContextSwitchReason( uint8_t reason );
+    static const char* DecodeContextSwitchReasonCode( uint8_t reason );
+
+    tracy_force_inline bool& Vis( const void* ptr )
+    {
+        auto it = m_visMap.find( ptr );
+        if( it == m_visMap.end() ) it = m_visMap.emplace( ptr, true ).first;
+        return it->second;
+    }
 
     Worker m_worker;
     std::string m_filename, m_filenameStaging;
@@ -380,11 +412,14 @@ private:
     uint64_t m_totalMemory;
 
     ViewData m_vd;
+    TimelineController m_tc;
+    KeyboardNavigation m_kbNavCtrl;
 
     const ZoneEvent* m_zoneInfoWindow = nullptr;
     const ZoneEvent* m_zoneHighlight;
     DecayValue<int16_t> m_zoneSrcLocHighlight = 0;
     LockHighlight m_lockHighlight { -1 };
+    LockHighlight m_nextLockHighlight;
     DecayValue<const MessageData*> m_msgHighlight = nullptr;
     DecayValue<uint32_t> m_lockHoverHighlight = InvalidId;
     DecayValue<const MessageData*> m_msgToFocus = nullptr;
@@ -407,6 +442,7 @@ private:
     bool m_showMessageImages = false;
     int m_visibleMessages = 0;
     size_t m_prevMessages = 0;
+    bool m_messagesShowCallstack = false;
     Vector<uint32_t> m_msgList;
     bool m_disconnectIssued = false;
     DecayValue<uint64_t> m_drawThreadMigrations = 0;
@@ -450,6 +486,7 @@ private:
     bool m_allocTimeRelativeToZone = true;
     bool m_ctxSwitchTimeRelativeToZone = true;
     bool m_messageTimeRelativeToZone = true;
+    bool m_messagesExcludeChildren = true;
     uint64_t m_zoneInfoMemPool = 0;
     int m_waitStack = 0;
     int m_waitStackMode = 0;
@@ -457,7 +494,7 @@ private:
     bool m_groupWaitStackTopDown = true;
 
     ShortcutAction m_shortcut = ShortcutAction::None;
-    Namespace m_namespace = Namespace::Short;
+    ShortenName m_shortenName = ShortenName::NoSpaceAndNormalize;
     Animation m_zoomAnim;
     BuzzAnim<int> m_callstackBuzzAnim;
     BuzzAnim<int> m_sampleParentBuzzAnim;
@@ -483,16 +520,16 @@ private:
     float m_rootWidth, m_rootHeight;
     SetTitleCallback m_stcb;
     bool m_titleSet = false;
-    GetWindowCallback m_gwcb;
     SetScaleCallback m_sscb;
+    AttentionCallback m_acb;
 
     float m_notificationTime = 0;
     std::string m_notificationText;
 
     bool m_groupCallstackTreeByNameBottomUp = true;
     bool m_groupCallstackTreeByNameTopDown = true;
-    bool m_activeOnlyBottomUp = false;
-    bool m_activeOnlyTopDown = false;
+    MemRange m_memRangeBottomUp = MemRange::Full;
+    MemRange m_memRangeTopDown = MemRange::Full;
 
     enum class SaveThreadState
     {
@@ -522,6 +559,7 @@ private:
     std::vector<std::unique_ptr<Annotation>> m_annotations;
     UserData m_userData;
 
+    bool m_wasActive = false;
     bool m_reconnectRequested = false;
     bool m_firstFrame = true;
     std::chrono::time_point<std::chrono::high_resolution_clock> m_firstFrameTime;
@@ -536,8 +574,12 @@ private:
     unordered_flat_map<int16_t, StatisticsCache> m_statCache;
     unordered_flat_map<int16_t, StatisticsCache> m_gpuStatCache;
 
+    unordered_flat_map<const void*, bool> m_visMap;
+
     void(*m_cbMainThread)(std::function<void()>, bool);
 
+    int m_gpuIdx = 0;
+
     struct FindZone {
         enum : uint64_t { Unselected = std::numeric_limits<uint64_t>::max() - 1 };
         enum class GroupBy : int { Thread, UserText, ZoneName, Callstack, Parent, NoGrouping };
@@ -699,6 +741,11 @@ private:
         int64_t total[2];
         int minBinVal = 1;
         int compareMode = 0;
+        bool diffDone = false;
+        bool diffDirection;
+        std::vector<const char*> thisUnique;
+        std::vector<const char*> secondUnique;
+        std::vector<std::pair<const char*, std::string>> diffs;
 
         void ResetSelection()
         {
@@ -720,6 +767,10 @@ private:
                 match[i].clear();
                 selMatch[i] = 0;
             }
+            diffDone = false;
+            thisUnique.clear();
+            secondUnique.clear();
+            diffs.clear();
         }
     } m_compare;
 
@@ -785,7 +836,21 @@ private:
         bool groupTopDown = true;
     } m_sampleParents;
 
+    struct
+    {
+        bool enabled = false;
+        bool monitor = false;
+        int64_t time;
+    } m_sendQueueWarning;
+
     std::vector<std::pair<int, int>> m_cpuUsageBuf;
+
+    bool m_attnProtoMismatch = false;
+    bool m_attnNotAvailable = false;
+    bool m_attnDropped = false;
+    bool m_attnFailure = false;
+    bool m_attnWorking = false;
+    bool m_attnDisconnected = false;
 };
 
 }
