@@ -18,7 +18,6 @@ using WixSharp.CommonTasks;
 public struct Features {
 	public bool overlay;
 	public bool g15;
-	public bool rnnoise;
 }
 
 public class ClientInstaller : MumbleInstall {
@@ -87,14 +86,11 @@ public class ClientInstaller : MumbleInstall {
 			// 64 bit
 			this.Platform = WixSharp.Platform.x64;
 			binaries = new List<string>() {
+				"renamenoise.dll",
 				"speexdsp.dll",
 				"mumble.exe",
 			};
 
-			if (features.rnnoise) {
-				binaries.Add("rnnoise.dll");
-			}
-
 			if (features.overlay) {
 				binaries.Add("mumble_ol.dll");
 				binaries.Add("mumble_ol_helper.exe");
@@ -109,14 +105,11 @@ public class ClientInstaller : MumbleInstall {
 			// 32 bit
 			this.Platform = WixSharp.Platform.x86;
 			binaries = new List<string>() {
+				"renamenoise.dll",
 				"speexdsp.dll",
 				"mumble.exe",
 			};
 
-			if (features.rnnoise) {
-				binaries.Add("rnnoise.dll");
-			}
-
 			if (features.overlay) {
 				binaries.Add("mumble_ol.dll");
 				binaries.Add("mumble_ol_helper.exe");
@@ -221,10 +214,6 @@ class BuildInstaller
 			if (args[i] == "--overlay") {
 				features.overlay = true;
 			}
-
-			if (args[i] == "--rnnoise") {
-				features.rnnoise = true;
-			}
 		}
 
 		if (version != null && arch != null) {
