@@ -1,12 +1,11 @@
-// Copyright 2021-2022 The Mumble Developers. All rights reserved.
+// Copyright 2021-2023 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
 
 // Include the definitions of the plugin functions
 // Not that this will also include ../PluginComponents.h
-#include "../MumbleAPI_v_1_0_x.h"
-#include "../MumblePlugin_v_1_0_x.h"
+#include "../MumblePlugin.h"
 
 #include <cstring>
 #include <iostream>
