@@ -1,4 +1,4 @@
-// Copyright 2017-2022 The Mumble Developers. All rights reserved.
+// Copyright 2017-2023 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
@@ -24,6 +24,6 @@ bool setenv(QString name, QString value);
 
 bool waylandIsUsed();
 
-}; // namespace EnvUtils
+} // namespace EnvUtils
 
 #endif
