@@ -1,4 +1,4 @@
-// Copyright 2009-2022 The Mumble Developers. All rights reserved.
+// Copyright 2009-2023 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
@@ -54,7 +54,7 @@ public:
 			memcpy(&data[offset], d, len);
 			offset += len;
 		} else {
-			int l = left();
+			unsigned int l = left();
 			memset(&data[offset], 0, l);
 			offset += l;
 			overshoot += len - l;
@@ -99,7 +99,7 @@ public:
 
 	QByteArray dataBlock(quint32 len) {
 		if (len <= left()) {
-			QByteArray a(charPtr(), len);
+			QByteArray a(charPtr(), static_cast< int >(len));
 			offset += len;
 			return a;
 		} else {
@@ -109,7 +109,7 @@ public:
 	}
 
 protected:
-	void setup(unsigned char *d, int msize) {
+	void setup(unsigned char *d, unsigned int msize) {
 		data      = d;
 		offset    = 0;
 		overshoot = 0;
@@ -118,23 +118,24 @@ protected:
 	}
 
 public:
-	PacketDataStream(const unsigned char *d, int msize) { setup(const_cast< unsigned char * >(d), msize); };
+	PacketDataStream(const unsigned char *d, unsigned int msize) { setup(const_cast< unsigned char * >(d), msize); };
 
-	PacketDataStream(const char *d, int msize) {
+	PacketDataStream(const char *d, unsigned int msize) {
 		setup(const_cast< unsigned char * >(reinterpret_cast< const unsigned char * >(d)), msize);
 	};
 
-	PacketDataStream(char *d, int msize) { setup(reinterpret_cast< unsigned char * >(d), msize); };
+	PacketDataStream(char *d, unsigned int msize) { setup(reinterpret_cast< unsigned char * >(d), msize); };
 
-	PacketDataStream(unsigned char *d, int msize) { setup(d, msize); };
+	PacketDataStream(unsigned char *d, unsigned int msize) { setup(d, msize); };
 
 	PacketDataStream(const QByteArray &qba) {
-		setup(const_cast< unsigned char * >(reinterpret_cast< const unsigned char * >(qba.constData())), qba.size());
+		setup(const_cast< unsigned char * >(reinterpret_cast< const unsigned char * >(qba.constData())),
+			  static_cast< unsigned int >(qba.size()));
 	}
 
 	PacketDataStream(QByteArray &qba) {
 		unsigned char *ptr = reinterpret_cast< unsigned char * >(qba.data());
-		setup(ptr, qba.capacity());
+		setup(ptr, static_cast< unsigned int >(qba.capacity()));
 	}
 
 	PacketDataStream &operator<<(const quint64 value) {
@@ -144,40 +145,46 @@ public:
 			// Signed number.
 			i = ~i;
 			if (i <= 0x3) {
-				// Shortcase for -1 to -4
+				// Special case for -1 to -4. The most significant bits of the first byte must be (in binary) 111111
+				// followed by the 2 bits representing the absolute value of the encoded number. Shortcase for -1 to -4
 				append(0xFC | i);
 				return *this;
 			} else {
+				// Add flag byte, whose most significant bits are (in binary) 111110 that indicates
+				// that what follows is the varint encoding of the absolute value of i, but that the
+				// value itself is supposed to be negative.
 				append(0xF8);
 			}
 		}
 		if (i < 0x80) {
-			// Need top bit clear
+			// Encode as 7-bit, positive number -> most significant bit of first byte must be zero
 			append(i);
 		} else if (i < 0x4000) {
-			// Need top two bits clear
+			// Encode as 14-bit, positive number -> most significant bits of first byte must be (in binary) 10
 			append((i >> 8) | 0x80);
 			append(i & 0xFF);
 		} else if (i < 0x200000) {
-			// Need top three bits clear
+			// Encode as 21-bit, positive number -> most significant bits of first byte must be (in binary) 110
 			append((i >> 16) | 0xC0);
 			append((i >> 8) & 0xFF);
 			append(i & 0xFF);
 		} else if (i < 0x10000000) {
-			// Need top four bits clear
+			// Encode as 28-bit, positive number -> most significant bits of first byte must be (in binary) 1110
 			append((i >> 24) | 0xE0);
 			append((i >> 16) & 0xFF);
 			append((i >> 8) & 0xFF);
 			append(i & 0xFF);
 		} else if (i < 0x100000000LL) {
-			// It's a full 32-bit integer.
+			// Encode as 32-bit, positive number -> most significant bits of first byte must be (in binary) 111100
+			// Remaining bits in first byte remain unused
 			append(0xF0);
 			append((i >> 24) & 0xFF);
 			append((i >> 16) & 0xFF);
 			append((i >> 8) & 0xFF);
 			append(i & 0xFF);
 		} else {
-			// It's a 64-bit value.
+			// Encode as 64-bit, positive number -> most significant bits of first byte must be (in binary) 111101
+			// Remaining bits in first byte remain unused
 			append(0xF4);
 			append((i >> 56) & 0xFF);
 			append((i >> 48) & 0xFF);
@@ -230,7 +237,7 @@ public:
 
 	PacketDataStream &operator<<(const QByteArray &a) {
 		*this << a.size();
-		append(a.constData(), a.size());
+		append(a.constData(), static_cast< unsigned int >(a.size()));
 		return *this;
 	}
 
@@ -241,7 +248,7 @@ public:
 			len = left();
 			ok  = false;
 		}
-		a = QByteArray(reinterpret_cast< const char * >(&data[offset]), len);
+		a = QByteArray(reinterpret_cast< const char * >(&data[offset]), static_cast< int >(len));
 		offset += len;
 		return *this;
 	}
@@ -256,7 +263,7 @@ public:
 			len = left();
 			ok  = false;
 		}
-		s = QString::fromUtf8(reinterpret_cast< const char * >(&data[offset]), len);
+		s = QString::fromUtf8(reinterpret_cast< const char * >(&data[offset]), static_cast< int >(len));
 		offset += len;
 		return *this;
 	}
