@@ -1,4 +1,4 @@
-// Copyright 2019-2022 The Mumble Developers. All rights reserved.
+// Copyright 2019-2023 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
@@ -11,18 +11,13 @@
 
 #include <QtCore/QtGlobal>
 
-#define iroundf(x) (static_cast< int >(x))
-
-#ifdef Q_OS_WIN
-#	define STACKVAR(type, varname, count) type *varname = reinterpret_cast< type * >(_alloca(sizeof(type) * (count)))
-#else
+#ifndef Q_OS_WIN
 #	ifdef WId
 typedef WId HWND;
 #	endif
 #	define __cdecl
 #	define INVALID_SOCKET -1
 #	define SOCKET_ERROR -1
-#	define STACKVAR(type, varname, count) type varname[count]
 #	define CopyMemory(dst, ptr, len) memcpy(dst, ptr, len)
 #	define ZeroMemory(ptr, len) memset(ptr, 0, len)
 #endif
