@@ -138,10 +138,6 @@ ASIOInput *ASIOInput::aiSelf;
 ASIOConfig::ASIOConfig(Settings &st) : ConfigWidget(st) {
 	setupUi(this);
 
-	qcbDevice->setAccessibleName(tr("Device to use for microphone"));
-	qlwMic->setAccessibleName(tr("List of microphones"));
-	qlwSpeaker->setAccessibleName(tr("List of speakers"));
-
 	// List of devices known to misbehave or be totally useless
 	QStringList blacklist;
 	blacklist << QLatin1String("{a91eaba1-cf4c-11d3-b96a-00a0c9c7b61a}"); // ASIO DirectX
