@@ -13,11 +13,15 @@
 #include "AudioStats.h"
 #include "Settings.h"
 
+#include "widgets/EventFilters.h"
+
 class AudioWizard : public QWizard, public Ui::AudioWizard {
 private:
 	Q_OBJECT
 	Q_DISABLE_COPY(AudioWizard)
 
+	void updateEchoCheckbox(AudioInputRegistrar *air);
+
 	/// Which echo cancellation is usable depends on the audio backend and the device combination.
 	/// This function will iterate through the list of available echo cancellation in the audio backend and check with
 	/// the backend whether this echo cancellation option works for current device combination.
@@ -50,6 +54,8 @@ protected:
 	void playChord();
 
 	bool eventFilter(QObject *, QEvent *) Q_DECL_OVERRIDE;
+
+	OverrideTabOrderFilter *m_overrideFilter;
 public slots:
 	void on_qcbInput_activated(int);
 	void on_qcbInputDevice_activated(int);
