@@ -14,11 +14,13 @@
 #include <QtNetwork/QSslCertificate>
 
 #include "Settings.h"
+#include "widgets/AccessibleQGroupBox.h"
+#include "widgets/EventFilters.h"
 
 class QLabel;
 class QWidget;
 
-class CertView : public QGroupBox {
+class CertView : public AccessibleQGroupBox {
 private:
 	Q_OBJECT
 	Q_DISABLE_COPY(CertView)
@@ -37,6 +39,9 @@ class CertWizard : public QWizard, public Ui::Certificates {
 private:
 	Q_OBJECT
 	Q_DISABLE_COPY(CertWizard)
+
+	OverrideTabOrderFilter *m_overrideFilter;
+
 protected:
 	Settings::KeyPair kpCurrent, kpNew;
 
@@ -57,6 +62,7 @@ public slots:
 	void on_qleImportFile_textChanged(const QString &);
 	void on_qlePassword_textChanged(const QString &);
 	void on_qlIntroText_linkActivated(const QString &);
+	void showPage(int);
 };
 
 #endif
