@@ -1,4 +1,4 @@
-// Copyright 2007-2022 The Mumble Developers. All rights reserved.
+// Copyright 2007-2023 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
@@ -74,15 +74,16 @@ public:
 	Timer tDoublePush;
 	quint64 uiDoublePush;
 	/// Holds the current VoiceTarget ID to send audio to
-	int iTarget;
+	std::int32_t iTarget;
 	/// Holds the value of iTarget before its last change until the current
 	/// audio-stream ends (and it has a value > 0). See the comment in
 	/// AudioInput::flushCheck for further details on this.
-	int iPrevTarget;
+	std::int32_t iPrevTarget;
 	bool bPushToMute;
 	bool bCenterPosition;
 	bool bPosTest;
 	bool bInAudioWizard;
+	bool inConfigUI;
 #ifdef USE_OVERLAY
 	OverlayClient *ocIntercept;
 #endif
