@@ -1,4 +1,4 @@
-// Copyright 2022 The Mumble Developers. All rights reserved.
+// Copyright 2022-2023 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
@@ -37,6 +37,26 @@ enum Type {
 	ToggleTalkingUI,
 	ToggleSearch,
 	ListenToChannel,
+	ServerConnect,
+	ServerDisconnect,
+	ServerInformation,
+	ServerTokens,
+	ServerUserList,
+	ServerBanList,
+	SelfPrioritySpeaker,
+	Recording,
+	SelfComment,
+	ServerTexture,
+	ServerTextureRemove,
+	SelfRegister,
+	AudioStats,
+	ConfigDialog,
+	AudioWizard,
+	ConfigCert,
+	AudioTTS,
+	HelpAbout,
+	HelpAboutQt,
+	HelpVersionCheck,
 };
 
 // A few assertions meant to catch, if anyone inserts a new value in-between instead of appending
@@ -44,6 +64,7 @@ enum Type {
 static_assert(PushToTalk == 1, "You may only append to the end of the enum!");
 static_assert(ToggleMinimalView == 9, "You may only append to the end of the enum!");
 static_assert(ToggleSearch == 22, "You may only append to the end of the enum!");
+static_assert(HelpVersionCheck == 43, "You may only append to the end of the enum!");
 } // namespace GlobalShortcutType
 
 #endif // MUMBLE_MUMBLE_GLOBALSHORTCUTTYPES_H_
