@@ -76,9 +76,6 @@ static LCDDeviceManager devmgr;
 
 LCDConfig::LCDConfig(Settings &st) : ConfigWidget(st) {
 	setupUi(this);
-	qtwDevices->setAccessibleName(tr("Devices"));
-	qsMinColWidth->setAccessibleName(tr("Minimum column width"));
-	qsSplitterWidth->setAccessibleName(tr("Splitter width"));
 
 	QTreeWidgetItem *qtwi;
 	foreach (LCDDevice *d, devmgr.qlDevices) {
