@@ -1,4 +1,4 @@
-// Copyright 2007-2022 The Mumble Developers. All rights reserved.
+// Copyright 2007-2023 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
@@ -181,17 +181,8 @@ private:
 public:
 	LogDocument(QObject *p = nullptr);
 	QVariant loadResource(int, const QUrl &) Q_DECL_OVERRIDE;
-public slots:
-	void finished();
 };
 
-class LogDocumentResourceAddedEvent : public QEvent {
-public:
-	static const QEvent::Type Type = static_cast< QEvent::Type >(20145);
-
-	LogDocumentResourceAddedEvent();
-};
-
-Q_DECLARE_METATYPE(Log::MsgType);
+Q_DECLARE_METATYPE(Log::MsgType)
 
 #endif
