@@ -1,4 +1,4 @@
-// Copyright 2012-2022 The Mumble Developers. All rights reserved.
+// Copyright 2012-2023 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
@@ -7,9 +7,7 @@
 #include "MainWindow.h"
 #include "Settings.h"
 
-#ifdef USE_DBUS
-#	include <QtDBus/QDBusInterface>
-#endif
+#include <QDBusInterface>
 
 void Log::postNotification(MsgType mt, const QString &plain) {
 	// Message notification with balloon tooltips
@@ -30,7 +28,6 @@ void Log::postNotification(MsgType mt, const QString &plain) {
 			break;
 	}
 
-#ifdef USE_DBUS
 	QDBusMessage response;
 	QVariantMap hints;
 	hints.insert(QLatin1String("desktop-entry"), QLatin1String("mumble"));
@@ -66,9 +63,6 @@ void Log::postNotification(MsgType mt, const QString &plain) {
 	if (response.type() == QDBusMessage::ReplyMessage && response.arguments().count() == 1) {
 		uiLastId = response.arguments().at(0).toUInt();
 	} else {
-#else
-	if (true) {
-#endif
 		postQtNotification(mt, plain);
 	}
 }
