@@ -1,4 +1,4 @@
-// Copyright 2015-2022 The Mumble Developers. All rights reserved.
+// Copyright 2015-2023 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
@@ -11,7 +11,7 @@
 
 class OverlayPositionableItem : public QObject, public QGraphicsPixmapItem {
 	Q_OBJECT
-	Q_DISABLE_COPY(OverlayPositionableItem);
+	Q_DISABLE_COPY(OverlayPositionableItem)
 
 public:
 	OverlayPositionableItem(QRectF *posPtr, const bool isPositionable = false);
