@@ -1,4 +1,4 @@
-// Copyright 2019-2022 The Mumble Developers. All rights reserved.
+// Copyright 2019-2023 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
@@ -18,8 +18,8 @@ namespace Screen {
 	QWindow *windowFromWidget(const QWidget &widget);
 	QScreen *screenFromWidget(const QWidget &widget);
 	QScreen *screenAt(const QPoint &point);
-}; // namespace Screen
+} // namespace Screen
 
-}; // namespace Mumble
+} // namespace Mumble
 
 #endif
