@@ -1,4 +1,4 @@
-// Copyright 2021-2022 The Mumble Developers. All rights reserved.
+// Copyright 2021-2023 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
@@ -13,8 +13,8 @@
 class Connection;
 
 class ServerInformation : public QDialog, private Ui::ServerInformation {
-	Q_OBJECT;
-	Q_DISABLE_COPY(ServerInformation);
+	Q_OBJECT
+	Q_DISABLE_COPY(ServerInformation)
 
 public:
 	ServerInformation(QWidget *parent = nullptr);
