@@ -1,4 +1,4 @@
-// Copyright 2020-2022 The Mumble Developers. All rights reserved.
+// Copyright 2020-2023 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
@@ -18,7 +18,7 @@ class UserLocalNicknameDialog;
 
 class UserLocalNicknameDialog : public QDialog, private Ui::UserLocalNicknameDialog {
 	Q_OBJECT
-	Q_DISABLE_COPY(UserLocalNicknameDialog);
+	Q_DISABLE_COPY(UserLocalNicknameDialog)
 
 	/// The session ID for the user that the dialog is changing the nickname for.
 	unsigned int m_clientSession;
