@@ -1,4 +1,4 @@
-// Copyright 2009-2022 The Mumble Developers. All rights reserved.
+// Copyright 2009-2023 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
@@ -75,7 +75,8 @@ void UserDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
 	QRect textRect   = style->subElementRect(QStyle::SE_ItemViewItemText, &o, o.widget);
 	QString itemText = o.fontMetrics.elidedText(o.text, o.textElideMode, textRect.width());
 	painter->setFont(o.font);
-	style->drawItemText(painter, textRect, o.displayAlignment, o.palette, true, itemText, colorRole);
+	style->drawItemText(painter, textRect, static_cast< int >(o.displayAlignment), o.palette, true, itemText,
+						colorRole);
 
 	// draw icons to original rect
 	QRect ps = QRect(option.rect.right() - (ql.size() * m_iconTotalDimension), option.rect.y(),
