@@ -1,4 +1,4 @@
-// Copyright 2010-2022 The Mumble Developers. All rights reserved.
+// Copyright 2010-2023 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
@@ -139,7 +139,9 @@ void os_init() {
 
 	if (home) {
 		size_t len = strlen(home) + strlen(logpath) + 1;
-		STACKVAR(char, buff, len);
+		static std::vector<char> buffer;
+		buffer.resize(len);
+		char *buff = buffer.data();
 		memset(buff, 0, len);
 		strcat(buff, home);
 		strcat(buff, logpath);
