@@ -1,4 +1,4 @@
-// Copyright 2021-2022 The Mumble Developers. All rights reserved.
+// Copyright 2021-2023 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
@@ -18,8 +18,8 @@ class QModelIndex;
  * rich text support to the *View and *Widget objects (e.g. TreeWidget).
  */
 class RichTextItemDelegate : public QStyledItemDelegate {
-	Q_OBJECT;
-	Q_DISABLE_COPY(RichTextItemDelegate);
+	Q_OBJECT
+	Q_DISABLE_COPY(RichTextItemDelegate)
 
 public:
 	// inherit constructors
