@@ -6,6 +6,8 @@
 #ifndef MUMBLE_MUMBLE_WIDGETS_SEARCHDIALOGTREE_H_
 #define MUMBLE_MUMBLE_WIDGETS_SEARCHDIALOGTREE_H_
 
+#include <QAbstractItemView>
+#include <QModelIndex>
 #include <QTreeWidget>
 
 class QResizeEvent;
@@ -14,6 +16,8 @@ class SearchDialogTree : public QTreeWidget {
 public:
 	using QTreeWidget::QTreeWidget;
 
+	QModelIndex moveCursor(QAbstractItemView::CursorAction cursorAction, Qt::KeyboardModifiers modifiers) override;
+
 protected:
 	void resizeEvent(QResizeEvent *event) override;
 };
