@@ -1,4 +1,4 @@
-// Copyright 2007-2022 The Mumble Developers. All rights reserved.
+// Copyright 2007-2023 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
@@ -18,7 +18,7 @@ class QSqlDatabase;
 class QSqlQuery;
 
 class ServerDB : public QObject {
-	Q_OBJECT;
+	Q_OBJECT
 
 public:
 	/// A version number that allows us to keep track of changes we make to the DB architecture
