@@ -1,4 +1,4 @@
-// Copyright 2010-2022 The Mumble Developers. All rights reserved.
+// Copyright 2010-2023 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
@@ -15,7 +15,7 @@
 
 ServerUser::ServerUser(Server *p, QSslSocket *socket)
 	: Connection(p, socket), User(), s(nullptr), leakyBucket(p->iMessageLimit, p->iMessageBurst),
-	  m_pluginMessageBucket(5, 20) {
+	  m_pluginMessageBucket(p->iPluginMessageLimit, p->iPluginMessageBurst) {
 	sState       = ServerUser::Connected;
 	m_clientType = ClientType::REGULAR;
 	sUdpSocket   = INVALID_SOCKET;
@@ -55,7 +55,7 @@ bool BandwidthRecord::addFrame(int size, int maxpersec) {
 		return false;
 
 	int nsum = iSum - a_iBW[iRecNum] + size;
-	int bw   = static_cast< int >((nsum * 1000000LL) / elapsed);
+	int bw   = static_cast< int >((static_cast< quint64 >(nsum) * 1000000ULL) / elapsed);
 
 	if (bw > maxpersec)
 		return false;
@@ -114,7 +114,7 @@ int BandwidthRecord::bandwidth() const {
 	if (elapsed < 250000ULL)
 		return 0;
 
-	return static_cast< int >((sum * 1000000ULL) / elapsed);
+	return static_cast< int >((static_cast< quint64 >(sum) * 1000000ULL) / elapsed);
 }
 
 LeakyBucket::LeakyBucket(unsigned int tokensPerSec, unsigned int maxTokens)
