@@ -1,4 +1,4 @@
-// Copyright 2007-2022 The Mumble Developers. All rights reserved.
+// Copyright 2007-2023 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
@@ -16,7 +16,7 @@ class QAction;
 class Tray : public QObject {
 private:
 	Q_OBJECT
-	Q_DISABLE_COPY(Tray);
+	Q_DISABLE_COPY(Tray)
 
 protected:
 	QSystemTrayIcon *qsti;
