@@ -1,4 +1,4 @@
-// Copyright 2009-2022 The Mumble Developers. All rights reserved.
+// Copyright 2009-2023 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
@@ -9,7 +9,7 @@
 #include <boost/signals.hpp>
 
 class Slotter : public QObject {
-	Q_OBJECT;
+	Q_OBJECT
 
 public:
 	Slotter(QObject *p = nullptr) : QObject(p){};
@@ -18,7 +18,7 @@ public Q_SLOTS:
 };
 
 class Emitter : public QObject {
-	Q_OBJECT;
+	Q_OBJECT
 
 public:
 	Slotter *s;
